@@ -1,6 +1,7 @@
 import boto3
+from datetime import datetime
+from magicdb import FrontendParserModel, DateModel, MagicModel
 
-from magicdb.Models import DateModel, MagicModel
 # from magicapi import settings
 # from magicapi.Globals.G import g
 
@@ -10,6 +11,8 @@ from magicapi import g
 dynamodb = boto3.resource("dynamodb")
 table = dynamodb.Table(g.settings.tasks_table_name)
 
+# this is deprecated, only used if you want to use dynamo as Q
+
 
 class TaskParams(MagicModel):
     args: list
@@ -32,4 +35,3 @@ class Task(DateModel):
     @staticmethod
     def get_table():
         return table
-
